#!/usr/bin/env python

import os
from configargparse import ArgumentParser


def check(args):
    """
    Confirm the existence of input files and output directory, and read the input files.

    Parameters
    ----------
    args : Namespace

    Returns
    -------
    tuple of str
        A tuple containing the content of the first and second input documents.

    Raises
    ------
    SystemExit
        If any of the input files or the output directory do not exist, the program will print an error message and
        stop.
    """
    # Confirm that both input files exist
    if not os.path.exists(args.input_path_1):
        raise FileNotFoundError(f"The file from the first input does not exist {args.input_path_1}.")
    if not os.path.exists(args.input_path_2):
        raise FileNotFoundError(f"The file from the second input does not exist {args.input_path_2}.")
    # Confirm that the output directory exists
    if not os.path.isdir(args.output_path):
        raise FileNotFoundError(f"The output directory does not exist {args.output_path}.")


def read_arguments():
    """
    Parse and return the command-line arguments for input and output file paths.

    This function defines the command-line arguments for processing input files and the output file/directory,
    and then parses these arguments to extract their values.

    Returns
    -------
    tuple of str
        A tuple containing:
        - input_path_1 (str): The path of the first input file.
        - input_path_2 (str): The path of the second input file.
        - output_path (str): The path of the output directory.
        - output_name (str or None): The name of the output file (optional).
    """
    parser = ArgumentParser(description='Process_files')

    # Define the inputs (-i and -g) and the output (-o)
    parser.add_argument("-i", "--input1", "input_path_1", type=str, required=True,
                        help="The path of the first input file")
    parser.add_argument("-g", "--input2", "input_path_2", type=str, required=True,
                        help="The path of the second input file")
    parser.add_argument("-o", "--output", "output_path", type=str, required=True,
                        help="The path of the output directory")
    parser.add_argument("-n", "--doc_name", type=str, required=False,
                        help="The name of the output file (optional)")

    args = parser.parse_args()
    check(args)

    return args
